fn current_accent(data: &Drawing<'_>, target: RoleTarget) -> Option<u8>Expand description
The accent index target carries now, or None when it has none.
fn current_accent(data: &Drawing<'_>, target: RoleTarget) -> Option<u8>The accent index target carries now, or None when it has none.