shared_dir

Function shared_dir 

fn shared_dir(data: &Drawing<'_>, pins: &[PinId]) -> Option<PinDir>
The one direction every pin in pins is facing, or None where they disagree or the selection has gone.