pub struct Reading {
pub tool: Option<Cow<'static, str>>,
pub selection: Option<String>,
pub zoom: Zoom,
pub cursor: Option<GridCell>,
pub title: TitleBlock,
}Expand description
Everything the status line could say, before its priority picks one.
Fields
tool: Option<Cow<'static, str>>How to use the armed tool, while one is armed.
selection: Option<String>The path to what is selected, while something is.
zoom: Zoomcursor: Option<GridCell>The grid cell under the pointer, while it is over the canvas.
title: TitleBlockTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Reading
impl<'de> Deserialize<'de> for Reading
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Reading
impl StructuralPartialEq for Reading